@@ -34,7 +34,7 @@ class Password;
  */
 class KOPETE_EXPORT PasswordedAccount : public Account
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
