@@ -30,7 +30,7 @@ class TQListViewItem;
 
 class LatexPreferences : public TDECModule
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 
