@@ -47,19 +47,19 @@ ICQReadAway::ICQReadAway(ICQContact *c, TQWidget *parent, const char* name)
 	awayMessageBrowser->setText(mContact->awayMessage());
 
 	TQObject::connect(
-		awayMessageBrowser, TQT_SIGNAL(urlClick(const TQString&)),
-		this, TQT_SLOT(slotUrlClicked(const TQString&)));
+		awayMessageBrowser, TQ_SIGNAL(urlClick(const TQString&)),
+		this, TQ_SLOT(slotUrlClicked(const TQString&)));
 	TQObject::connect(
-		awayMessageBrowser, TQT_SIGNAL(mailClick(const TQString&, const TQString&)),
-		this, TQT_SLOT(slotMailClicked(const TQString&, const TQString&)));
+		awayMessageBrowser, TQ_SIGNAL(mailClick(const TQString&, const TQString&)),
+		this, TQ_SLOT(slotMailClicked(const TQString&, const TQString&)));
 
-	connect(this, TQT_SIGNAL(user1Clicked()),
-		this, TQT_SLOT(slotFetchAwayMessage()));
-	connect(this, TQT_SIGNAL(closeClicked()),
-		this, TQT_SLOT(slotCloseClicked()));
+	connect(this, TQ_SIGNAL(user1Clicked()),
+		this, TQ_SLOT(slotFetchAwayMessage()));
+	connect(this, TQ_SIGNAL(closeClicked()),
+		this, TQ_SLOT(slotCloseClicked()));
 
-	connect(c, TQT_SIGNAL(awayMessageChanged()),
-		this, TQT_SLOT(slotAwayMessageChanged()));
+	connect(c, TQ_SIGNAL(awayMessageChanged()),
+		this, TQ_SLOT(slotAwayMessageChanged()));
 
 	slotFetchAwayMessage();
 }
