@@ -111,9 +111,9 @@ void WebcamTask::parseWebcamInformation( YMSGTransfer *t )
 	KStreamSocket *socket = new KStreamSocket( info.server, TQString::number(5100) );
 	socketMap[socket] = info;
 	socket->enableRead( true );
-	connect( socket, TQT_SIGNAL( connected( const KResolverEntry& ) ), this, TQT_SLOT( slotConnectionStage1Established() ) );
-	connect( socket, TQT_SIGNAL( gotError(int) ), this, TQT_SLOT( slotConnectionFailed(int) ) );
-	connect( socket, TQT_SIGNAL( readyRead() ), this, TQT_SLOT( slotRead() ) );
+	connect( socket, TQ_SIGNAL( connected( const KResolverEntry& ) ), this, TQ_SLOT( slotConnectionStage1Established() ) );
+	connect( socket, TQ_SIGNAL( gotError(int) ), this, TQ_SLOT( slotConnectionFailed(int) ) );
+	connect( socket, TQ_SIGNAL( readyRead() ), this, TQ_SLOT( slotRead() ) );
 
 	socket->connect();
 }
@@ -124,8 +124,8 @@ void WebcamTask::slotConnectionStage1Established()
 	if( !socket )
 		return;
 	kdDebug(YAHOO_RAW_DEBUG) << "Webcam connection Stage1 to the user " << socketMap[socket].sender << " established." << endl;
-	disconnect( socket, TQT_SIGNAL( connected( const KResolverEntry& ) ), this, TQT_SLOT( slotConnectionStage1Established() ) );
-	disconnect( socket, TQT_SIGNAL( gotError(int) ), this, TQT_SLOT( slotConnectionFailed(int) ) );
+	disconnect( socket, TQ_SIGNAL( connected( const KResolverEntry& ) ), this, TQ_SLOT( slotConnectionStage1Established() ) );
+	disconnect( socket, TQ_SIGNAL( gotError(int) ), this, TQ_SLOT( slotConnectionFailed(int) ) );
 	socketMap[socket].status = ConnectedStage1;
 
 
@@ -157,8 +157,8 @@ void WebcamTask::slotConnectionStage2Established()
 		return;
 
 	kdDebug(YAHOO_RAW_DEBUG) << "Webcam connection Stage2 to the user " << socketMap[socket].sender << " established." << endl;
-	disconnect( socket, TQT_SIGNAL( connected( const KResolverEntry& ) ), this, TQT_SLOT( slotConnectionStage2Established() ) );
-	disconnect( socket, TQT_SIGNAL( gotError(int) ), this, TQT_SLOT( slotConnectionFailed(int) ) );
+	disconnect( socket, TQ_SIGNAL( connected( const KResolverEntry& ) ), this, TQ_SLOT( slotConnectionStage2Established() ) );
+	disconnect( socket, TQ_SIGNAL( gotError(int) ), this, TQ_SLOT( slotConnectionFailed(int) ) );
 	socketMap[socket].status = ConnectedStage2;
 
 	TQByteArray buffer;
@@ -211,7 +211,7 @@ void WebcamTask::slotRead()
 	switch( socketMap[socket].status )
 	{
 		case ConnectedStage1:
-			disconnect( socket, TQT_SIGNAL( readyRead() ), this, TQT_SLOT( slotRead() ) );
+			disconnect( socket, TQ_SIGNAL( readyRead() ), this, TQ_SLOT( slotRead() ) );
 			connectStage2( socket );
 		break;
 		case ConnectedStage2:
@@ -255,13 +255,13 @@ void WebcamTask::connectStage2( KStreamSocket *socket )
 		newSocket = new KStreamSocket( server, TQString::number(5100) );
 		socketMap[newSocket] = socketMap[socket];
 		newSocket->enableRead( true );
-		connect( newSocket, TQT_SIGNAL( connected( const KResolverEntry& ) ), this, TQT_SLOT( slotConnectionStage2Established() ) );
-		connect( newSocket, TQT_SIGNAL( gotError(int) ), this, TQT_SLOT( slotConnectionFailed(int) ) );
-		connect( newSocket, TQT_SIGNAL( readyRead() ), this, TQT_SLOT( slotRead() ) );
+		connect( newSocket, TQ_SIGNAL( connected( const KResolverEntry& ) ), this, TQ_SLOT( slotConnectionStage2Established() ) );
+		connect( newSocket, TQ_SIGNAL( gotError(int) ), this, TQ_SLOT( slotConnectionFailed(int) ) );
+		connect( newSocket, TQ_SIGNAL( readyRead() ), this, TQ_SLOT( slotRead() ) );
 		if( socketMap[newSocket].direction == Outgoing )
 		{
 			newSocket->enableWrite( true );
-			connect( newSocket, TQT_SIGNAL( readyWrite() ), this, TQT_SLOT( transmitWebcamImage() ) );
+			connect( newSocket, TQ_SIGNAL( readyWrite() ), this, TQ_SLOT( transmitWebcamImage() ) );
 		}
 
 		newSocket->connect();
@@ -635,7 +635,7 @@ void WebcamTask::sendEmptyWebcamImage()
 	pictureBuffer.resize( 0 );
 	transmissionPending = true;
 
-	TQTimer::singleShot( 1000, this, TQT_SLOT(sendEmptyWebcamImage()) );
+	TQTimer::singleShot( 1000, this, TQ_SLOT(sendEmptyWebcamImage()) );
 
 }
 
