@@ -32,7 +32,7 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#ifdef USE_SOLARIS
+#ifdef Q_OS_SOLARIS
 #include <strings.h>
 #endif
 
@@ -411,14 +411,14 @@ RFBController::RFBController(Configuration *c) :
 	forcedClose(false)
 {
 	self = this;
-	connect(&dialog, TQT_SIGNAL(okClicked()), TQT_SLOT(dialogAccepted()));
-	connect(&dialog, TQT_SIGNAL(cancelClicked()), TQT_SLOT(dialogRefused()));
-	connect(&initIdleTimer, TQT_SIGNAL(timeout()), TQT_SLOT(checkAsyncEvents()));
-	connect(&idleTimer, TQT_SIGNAL(timeout()), TQT_SLOT(idleSlot()));
+	connect(&dialog, TQ_SIGNAL(okClicked()), TQ_SLOT(dialogAccepted()));
+	connect(&dialog, TQ_SIGNAL(cancelClicked()), TQ_SLOT(dialogRefused()));
+	connect(&initIdleTimer, TQ_SIGNAL(timeout()), TQ_SLOT(checkAsyncEvents()));
+	connect(&idleTimer, TQ_SIGNAL(timeout()), TQ_SLOT(idleSlot()));
 
 	clipboard = TQApplication::clipboard();
-	connect(clipboard, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(selectionChanged()));
-	connect(clipboard, TQT_SIGNAL(dataChanged()), this, TQT_SLOT(clipboardChanged()));
+	connect(clipboard, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(selectionChanged()));
+	connect(clipboard, TQ_SIGNAL(dataChanged()), this, TQ_SLOT(clipboardChanged()));
 
 	asyncQueue.setAutoDelete(true);
 
@@ -543,7 +543,7 @@ void RFBController::stopServer(bool xtestUngrab)
 
 	if (xtestUngrab) {
 		disabler.disable = true;
-		TQTimer::singleShot(0, &disabler, TQT_SLOT(exec()));
+		TQTimer::singleShot(0, &disabler, TQ_SLOT(exec()));
 	}
 }
 
