@@ -37,17 +37,17 @@ FilterRuleEditor::FilterRuleEditor
   newHighlight(0);
 
   // ### split "OkPressed()" into 2 slots
-  connect( filter->ModifyButton, TQT_SIGNAL(clicked()), TQT_SLOT(OkPressed()) );
-  connect( filter->InsertButton, TQT_SIGNAL(clicked()), TQT_SLOT(OkPressed()) );
+  connect( filter->ModifyButton, TQ_SIGNAL(clicked()), TQ_SLOT(OkPressed()) );
+  connect( filter->InsertButton, TQ_SIGNAL(clicked()), TQ_SLOT(OkPressed()) );
 
-  connect( filter->NewButton, TQT_SIGNAL(clicked()), TQT_SLOT(newRule()) );
-  connect( filter->DeleteButton, TQT_SIGNAL(clicked()), TQT_SLOT(deleteRule()) );
+  connect( filter->NewButton, TQ_SIGNAL(clicked()), TQ_SLOT(newRule()) );
+  connect( filter->DeleteButton, TQ_SIGNAL(clicked()), TQ_SLOT(deleteRule()) );
 
-  connect( filter->UpButton, TQT_SIGNAL(clicked()), TQT_SLOT(raiseRule()) );
-  connect( filter->DownButton, TQT_SIGNAL(clicked()), TQT_SLOT(lowerRule()) );
+  connect( filter->UpButton, TQ_SIGNAL(clicked()), TQ_SLOT(raiseRule()) );
+  connect( filter->DownButton, TQ_SIGNAL(clicked()), TQ_SLOT(lowerRule()) );
 
-  connect( filter->RuleList, TQT_SIGNAL(highlighted(int)), TQT_SLOT(newHighlight(int)) );
-  connect( filter->RuleList, TQT_SIGNAL(selected(int)), TQT_SLOT(newHighlight(int)) );
+  connect( filter->RuleList, TQ_SIGNAL(highlighted(int)), TQ_SLOT(newHighlight(int)) );
+  connect( filter->RuleList, TQ_SIGNAL(selected(int)), TQ_SLOT(newHighlight(int)) );
 
 
   filter->RuleList->setHScrollBarMode( TQListBox::AlwaysOff );
